@@ -18,7 +18,7 @@ def main():
     for line in sys.stdin:
         ints = [ int( f ) for f in line.split() ]
         if max( ints ) > len( table ):
-            raise "Alphabet size too large!"
-        print str.join( '', [ table[i] for i in ints ] )    
+            raise ValueError("Alphabet size too large!")
+        print str.join( '', [ table[i] for i in ints ] )
 
 if __name__ == "__main__": main()
